@@ -91,19 +91,16 @@ impl From<redis::ConnectionAddr> for ConnectionAddr {
 #[derive(Clone, Debug, Default)]
 #[cfg_attr(feature = "config", derive(serde::Deserialize))]
 pub struct ConnectionInfo {
-    addr: Box<ConnectionAddr>,
-    db: i64,
-    username: Option<String>,
-    passwd: Option<String>,
+    addr: ConnectionAddr,
+    #[cfg_attr(feature = "config", serde(flatten))]
+    redis: RedisConnectionInfo,
 }
 
 impl From<ConnectionInfo> for redis::ConnectionInfo {
     fn from(info: ConnectionInfo) -> Self {
         Self {
-            addr: Box::new((*info.addr).into()),
-            db: info.db,
-            username: info.username,
-            passwd: info.passwd,
+            addr: info.addr.into(),
+            redis: info.redis.into(),
         }
     }
 }
@@ -111,10 +108,8 @@ impl From<ConnectionInfo> for redis::ConnectionInfo {
 impl From<redis::ConnectionInfo> for ConnectionInfo {
     fn from(info: redis::ConnectionInfo) -> Self {
         Self {
-            addr: Box::new((*info.addr).into()),
-            db: info.db,
-            username: info.username,
-            passwd: info.passwd,
+            addr: info.addr.into(),
+            redis: info.redis.into(),
         }
     }
 }
@@ -125,6 +120,38 @@ impl redis::IntoConnectionInfo for ConnectionInfo {
     }
 }
 
+/// This is a 1:1 copy of the `redis::RedisConnectionInfo` struct.
+/// This is duplicated here in order to add support for the
+/// `serde::Deserialize` trait which is required for the `config`
+/// support.
+#[derive(Clone, Debug, Default)]
+#[cfg_attr(feature = "config", derive(serde::Deserialize))]
+pub struct RedisConnectionInfo {
+    pub db: i64,
+    pub username: Option<String>,
+    pub password: Option<String>,
+}
+
+impl From<RedisConnectionInfo> for redis::RedisConnectionInfo {
+    fn from(info: RedisConnectionInfo) -> Self {
+        Self {
+            db: info.db,
+            username: info.username,
+            password: info.password,
+        }
+    }
+}
+
+impl From<redis::RedisConnectionInfo> for RedisConnectionInfo {
+    fn from(info: redis::RedisConnectionInfo) -> Self {
+        Self {
+            db: info.db,
+            username: info.username,
+            password: info.password,
+        }
+    }
+}
+
 /// An error returned when pool creation fails.
 #[derive(Debug)]
 pub enum CreatePoolError {
@@ -182,8 +209,8 @@ impl std::error::Error for CreatePoolError {}
 #[derive(Clone, Debug)]
 #[cfg_attr(feature = "config", derive(serde::Deserialize))]
 pub struct Config {
-    /// Redis URL
-    /// See https://docs.rs/redis/0.20.0/redis/index.html#connection-parameters
+    /// Redis URL<br>
+    /// See [Connection Parameters](redis#connection-parameters)
     pub url: Option<String>,
     /// Redis ConnectionInfo structure
     pub connection: Option<ConnectionInfo>,
@@ -212,6 +239,15 @@ impl Config {
     pub fn get_pool_config(&self) -> PoolConfig {
         self.pool.clone().unwrap_or_default()
     }
+
+    /// Create the `Config` from a redis URL (like redis://127.0.0.1)
+    pub fn from_url<T: Into<String>>(url: T) -> Config {
+        Config {
+            url: Some(url.into()),
+            connection: None,
+            pool: None,
+        }
+    }
 }
 
 impl Default for Config {
